# TimeWarPY - Time Series Pre and Post Processing Methods

## Background and Objective

TimeWarPy is a library I created because I kept running into time-series related pre and post processing that is discussed a lot in ML literature but not standardized in a popular ML library. Most industry related forecasting methods are not well suited for real-time deep learning architectures. TimeWarPy is a stab at making these operations both fast and convenient for real-time applications through an easy to use set of core processing objections.

## General Use Case

## Installation

## Examples and Usage
